@@ -53,7 +53,7 @@ pquadInit <- function(mCall, LHS, data, ...){
                          upper = c(Inf, max(xy[,"x"]), Inf, Inf),
                          lower = c(-Inf, min(xy[,"x"]), -Inf, -Inf)), silent = TRUE)
 
-  if(class(op) != "try-error"){
+  if(!inherits(op, "try-error")){
     a <- op$par[1]
     xs <- op$par[2]
     b <- op$par[3]
